package com.jianshui.system.service;

import java.util.List;

import com.jianshui.common.core.domain.AjaxResult;
import com.jianshui.system.domain.ServiceManage;

/**
 * 服务管理Service接口
 *
 * @author Gong Quanlin
 * @date 2022-03-27
 */
public interface IServiceManageService {
    /**
     * 查询服务管理
     *
     * @param id 服务管理主键
     * @return 服务管理
     */
    public ServiceManage selectServiceManageById(Long id);

    /**
     * 查询服务管理列表
     *
     * @param serviceManage 服务管理
     * @return 服务管理集合
     */
    public List<ServiceManage> selectServiceManageList(ServiceManage serviceManage);

    /**
     * 新增服务管理
     *
     * @param serviceManage 服务管理
     * @return 结果
     */
    public int insertServiceManage(ServiceManage serviceManage);

    /**
     * 修改服务管理
     *
     * @param serviceManage 服务管理
     * @return 结果
     */
    public int updateServiceManage(ServiceManage serviceManage);

    /**
     * 批量删除服务管理
     *
     * @param ids 需要删除的服务管理主键集合
     * @return 结果
     */
    public int deleteServiceManageByIds(Long[] ids);

    /**
     * 删除服务管理信息
     *
     * @param id 服务管理主键
     * @return 结果
     */
    public int deleteServiceManageById(Long id);


    /**
     * 根据服务名称和companyId查询服务
     *
     * @param serviceName
     * @param companyid
     * @return
     */
    public ServiceManage selectServiceManageByCompanyIdAndServiceKey(String serviceName, Long companyid);


    /**
     * 获取销方对应的服务商信息
     *
     * @param serviceKey
     * @return 服务商对应的具体的compoent的key
     */
    public String getCompanyServiceSupplier(String serviceKey, Long companyid) throws Exception;

    /**
     * 对指定服务进行消费
     *
     * @param serviceKey
     * @param companyid
     * @return
     */
    public AjaxResult companyConsume(String serviceKey, Long companyid);

    /**
     * 获得入口请求适配器
     *
     * @param serviceKey
     * @param companyid
     * @return
     * @throws Exception
     */
    public String getRequestAdapterKey(String serviceKey, Long companyid) throws Exception;


    /**
     * 获得出口适配器
     *
     * @param serviceKey
     * @param companyid
     * @return
     * @throws Exception
     */
    public String getResponseAdapterKey(String serviceKey, Long companyid) throws Exception;
}
